[i-g-t V6 16/41] tests/kms_colorop: Add bypass test
Bhanuprakash Modem
bhanuprakash.modem at intel.com
Wed Apr 24 10:26:24 UTC 2024
From: Harry Wentland <harry.wentland at amd.com>
We want to test that setting the color pipeline to bypass
yields the expected results.
Signed-off-by: Harry Wentland <harry.wentland at amd.com>
---
tests/kms_colorop.c | 17 ++++++++++++-----
1 file changed, 12 insertions(+), 5 deletions(-)
diff --git a/tests/kms_colorop.c b/tests/kms_colorop.c
index e5c7377de..5b7f81c83 100644
--- a/tests/kms_colorop.c
+++ b/tests/kms_colorop.c
@@ -40,6 +40,7 @@
*
* arg[1]:
*
+ * @bypass: Bypass Color Pipeline
* @srgb_eotf: sRGB EOTF
* @srgb_inv_eotf: sRGB Inverse EOTF
* @srgb_eotf-srgb_inv_eotf: sRGB EOTF -> sRGB Inverse EOTF
@@ -440,13 +441,18 @@ static void colorop_plane_test(igt_display_t *display,
#endif
/* discover and set COLOR PIPELINE */
- /* get COLOR_PIPELINE enum */
- color_pipeline = get_color_pipeline(display, plane, colorops);
+ if (!colorops[0]) {
+ /* bypass test */
+ set_color_pipeline_bypass(plane);
+ } else {
+ /* get COLOR_PIPELINE enum */
+ color_pipeline = get_color_pipeline(display, plane, colorops);
- /* skip test if we can't find applicable pipeline */
- igt_skip_on(!color_pipeline);
+ /* skip test if we can't find applicable pipeline */
+ igt_skip_on(!color_pipeline);
- set_color_pipeline(display, plane, colorops, color_pipeline);
+ set_color_pipeline(display, plane, colorops, color_pipeline);
+ }
igt_output_set_writeback_fb(output, &output_fb);
@@ -487,6 +493,7 @@ igt_main
kms_colorop_t *colorops[MAX_COLOROPS];
const char *name;
} tests[] = {
+ { { NULL }, "bypass" },
{ { &kms_colorop_srgb_eotf, NULL }, "srgb_eotf" },
{ { &kms_colorop_srgb_inv_eotf, NULL }, "srgb_inv_eotf" },
{ { &kms_colorop_srgb_eotf, &kms_colorop_srgb_inv_eotf, NULL }, "srgb_eotf-srgb_inv_eotf" },
--
2.43.2
More information about the Intel-gfx-trybot
mailing list